@@ -11,21 +11,27 @@ import struct
 import sys
 import os
 try:
-    import ConfigParser
+    from ConfigParser import RawConfigParser
 except ImportError:
-    import configparser
+    from configparser import RawConfigParser
 
 import getpass
 DEFAULT_USER = getpass.getuser()
 
-from cymysql.charset import charset_by_name, charset_by_id
+try:
+    from cymysql.charsetx import charset_by_name, charset_by_id
+except ImportError:
+    from cymysql.charset import charset_by_name, charset_by_id
 try:
     from cymysql.cursorsx import Cursor
 except ImportError:
     from cymysql.cursors import Cursor
 from cymysql.constants.CLIENT import *
 from cymysql.constants.COMMAND import *
-from cymysql.converters import escape_item, encoders, decoders
+try:
+    from cymysql.convertersx import escape_item, encoders, decoders
+except:
+    from cymysql.converters import escape_item, encoders, decoders
 from cymysql.err import raise_mysql_exception, Warning, Error, \
      InterfaceError, DataError, DatabaseError, OperationalError, \
      IntegrityError, InternalError, NotSupportedError, ProgrammingError
@@ -236,7 +242,7 @@ class Connection(object):
             if not read_default_group:
                 read_default_group = "client"
 
-            cfg = ConfigParser.RawConfigParser()
+            cfg = RawConfigParser()
             cfg.read(os.path.expanduser(read_default_file))
 
             def _config(key, default):
@@ -438,7 +444,6 @@ class Connection(object):
                 self.host_info = "socket %s:%d" % (self.host, self.port)
                 if DEBUG: print('connected using socket')
             self.socket = sock
-            self.sock_fd = sock.fileno()
             self._get_server_information()
             self._request_authentication()
         except socket.error as e:
@@ -514,7 +519,6 @@ class Connection(object):
                                                  ssl_version=ssl.PROTOCOL_TLSv1,
                                                  cert_reqs=ssl.CERT_REQUIRED,
                                                  ca_certs=self.ca)
-            self.sock_fd = -1
 
         data = data_init + self.user+int2byte(0) + _scramble(self.password.encode(self.charset), self.salt)
 
